@@ -49,6 +49,83 @@ class Podcast(models.Model):
     facebook_username = models.CharField(max_length=30, null=True, blank=True)
     instagram_username = models.CharField(max_length=30, null=True, blank=True)
 
+    about_page = models.OneToOneField(
+        'Page',
+        on_delete=models.SET_NULL,
+        related_name='about_page_for',
+        null=True,
+        blank=True
+    )
+
+    ordering = models.CharField(
+        max_length=1,
+        choices=(
+            ('r', 'reverse-chronological'),
+            ('n', 'episode number')
+        ),
+        default='r'
+    )
+
+    colour_brand = models.CharField(
+        'brand',
+        max_length=8,
+        default='6219ff'
+    )
+
+    colour_white = models.CharField(
+        'white',
+        max_length=8,
+        default='ffffff'
+    )
+
+    colour_dark = models.CharField(
+        'dark',
+        max_length=8,
+        default='1c203c'
+    )
+
+    colour_text = models.CharField(
+        'text',
+        max_length=8,
+        default='1c203c'
+    )
+
+    colour_grey = models.CharField(
+        'grey',
+        max_length=8,
+        default='626265'
+    )
+
+    colour_error = models.CharField(
+        'error messages',
+        max_length=8,
+        default='d50000'
+    )
+
+    colour_success = models.CharField(
+        'success messages',
+        max_length=8,
+        default='008040'
+    )
+
+    colour_border = models.CharField(
+        'border',
+        max_length=8,
+        default='f3ece2'
+    )
+
+    bg_colour = models.CharField(
+        'background',
+        max_length=8,
+        default='ffffff'
+    )
+
+    bg_grey = models.CharField(
+        'grey background',
+        max_length=8,
+        default='f4f0eb'
+    )
+
     def __str__(self):
         return self.name
 
@@ -171,6 +248,22 @@ class Podcast(models.Model):
 
         return '//%s/%s' % (self.domain, path)
 
+    def get_rss_url(self):
+        if settings.DOMAINS_OR_SLUGS == 'slugs':
+            return '/%s/css/' % (self.slug)
+
+        return '//%s/css/' % (self.domain)
+
+    def get_order_by(self):
+        if self.ordering == 'n':
+            return (
+                'season__number',
+                'number',
+                'bonus'
+            )
+
+        return ('-published',)
+
     class Meta:
         ordering = ('name',)
 
