@@ -159,6 +159,8 @@ class EpisodeListView(PodcastMixin, SEOMixin, OpenGraphMixin, ListView):
                 categories__slug=self.request.GET['category']
             )
 
+        order_by = self.request.podcast.get_order_by()
+        queryset = queryset.order_by(*order_by)
         return queryset
 
     def get_context_data(self, **kwargs):
@@ -381,3 +383,12 @@ class FeedRedirectView(View):
         return HttpResponsePermanentRedirect(
             request.podcast.rss_feed_url
         )
+
+
+class PodcastStylesheetView(DetailView):
+    template_name = 'podcasts/styles.css'
+    content_type = 'text/css'
+    model = Podcast
+
+    def get_object(self):
+        return self.request.podcast
